package com.yanzhu.jh.project.mapper;

import com.yanzhu.jh.project.domain.SurProjectCostOutput;

import java.util.List;

/**
 * 项目成本产值Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-27
 */
public interface SurProjectCostOutputMapper 
{
    /**
     * 查询项目成本产值
     * 
     * @param id 项目成本产值主键
     * @return 项目成本产值
     */
    public SurProjectCostOutput selectSurProjectCostOutputById(Long id);

    /**
     * 查询项目成本产值列表
     * 
     * @param surProjectCostOutput 项目成本产值
     * @return 项目成本产值集合
     */
    public List<SurProjectCostOutput> selectSurProjectCostOutputList(SurProjectCostOutput surProjectCostOutput);

    /**
     * 新增项目成本产值
     * 
     * @param surProjectCostOutput 项目成本产值
     * @return 结果
     */
    public int insertSurProjectCostOutput(SurProjectCostOutput surProjectCostOutput);

    /**
     * 修改项目成本产值
     * 
     * @param surProjectCostOutput 项目成本产值
     * @return 结果
     */
    public int updateSurProjectCostOutput(SurProjectCostOutput surProjectCostOutput);

    /**
     * 删除项目成本产值
     * 
     * @param id 项目成本产值主键
     * @return 结果
     */
    public int deleteSurProjectCostOutputById(Long id);

    /**
     * 批量删除项目成本产值
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSurProjectCostOutputByIds(Long[] ids);

    public List<SurProjectCostOutput> selectYearAndMonth(SurProjectCostOutput where);

    List<SurProjectCostOutput> sumByDeptId(SurProjectCostOutput where);
}
